@@ -78,11 +78,4 @@ METADATA_VERSION_CHOICES = [
     1.2,
     1.1,
     1.0,
-]
-
-STRETCH_FUNCTION_CHOICES = [
-    'Linear',
-    'Log',
-    'Arcsinh(x)',
-    'X^(1/2)'
-]
+]
\ No newline at end of file
