@@ -43,6 +43,19 @@ def test_to_wcs(filename):
     a.to_wcs()
 
 
+@pytest.mark.parametrize('filename', XML_FILES_WCS)
+def test_to_wcs_target_image(filename, tmpdir):
+    from PIL import Image
+    image = Image.fromstring(data=b"1111", size=(2,2), mode="L")
+    image_file = tmpdir.join('test.png').strpath
+    image.save(image_file)
+    image.close()
+    a = AVM.from_xml_file(filename)
+    a.Spatial.ReferenceDimension = (30, 30)
+    a.to_wcs(target_image=image_file)
+
+
+
 @pytest.mark.parametrize('filename', NO_WCS)
 def test_to_wcs_nowcs(filename):
     a = AVM.from_xml_file(filename)
